.. Tomni documentation master file, created by
   sphinx-quickstart on Thu Jan  7 23:46:55 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
   
Welcome to Tomni documentation!
===================================
Tomni, developed and utilized by CytoSMART, is a dedicated Python package designed to simplify image analysis and streamline computer vision tasks. 
With its comprehensive set of functions and capabilities, Tomni offers an accessible solution for users seeking to harness the power of image analysis and computer vision in their projects. 
Detailed information on its functions and usage can be found in the following documentation, ensuring that you can make the most of Tomni's capabilities.

General
---------------------------------
General information regarding Tomni's implementations and formats.

.. toctree::
   :maxdepth: 1

   general

Functions
---------------------------------
Explore Tomni's image analysis and computer vision techniques.

.. toctree::
   :maxdepth: 1
   
   image_operations
   bbox_operations
   contour_operations
   json_operations
   transformers

Annotation Manager
---------------------------------
Take control of your annotations and streamline your workflow with Tomni's Annotation Manager.

.. toctree::
   :maxdepth: 1

   annotation_manager


Indices and tables
---------------------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
